<?php

/**
 * @file
 * Contains \Drupal\realname\Plugin\EntityReferenceSelection\RealnameSelection.
 */

namespace Drupal\realname\Plugin\EntityReferenceSelection;

use Drupal\Component\Utility\Html;
use Drupal\user\Plugin\EntityReferenceSelection\UserSelection;

/**
 * Provides specific access control for the user entity type.
 *
 * @EntityReferenceSelection(
 *   id = "realname:user",
 *   label = @Translation("User selection"),
 *   entity_types = {"user"},
 *   group = "realname",
 *   weight = 1
 * )
 */
class RealnameSelection extends UserSelection {

  /**
   * {@inheritdoc}
   * @todo I don't know why this is returning all users
   */
  protected function buildEntityQuery($match = NULL, $match_operator = 'CONTAINS') {
    //there are very limited options for altering an entityQuery, so at least
    //for now, we're going to build a new query from scratch rather than calling the parent
    //$query = parent::buildEntityQuery($match, $match_operator);
    $query = \Drupal::database()->select('users_field_data', 'u');
    $query->join('realname', 'r', 'r.uid = u.uid');
    $query->fields('u', ['uid'])
      ->addTag('user_access')
      ->addTag('entity_reference')
      // Add the Selection handler for system_query_entity_reference_alter().
      ->addMetaData('entity_reference_selection_handler', $this);
    
    if (!$this->currentUser->hasPermission('administer users')) {
      $query->condition('u.status', 1);
    }
    
    
    if (isset($handler_settings['target_bundles']) && is_array($handler_settings['target_bundles'])) {
      $query->condition($entity_type->getKey('bundle'), $handler_settings['target_bundles'], 'IN');
    }
    
    $match.='%';
    if (isset($match)) {
      $query->condition(db_or()
        ->condition('u.name', $match, 'LIKE')
        ->condition('r.realname', $match, 'LIKE')
      );
    }

    // Add the sort option.
    if (!empty($handler_settings['sort'])) {
      $sort_settings = $handler_settings['sort'];
      if ($sort_settings['field'] != '_none') {
        $query->sort($sort_settings['field'], $sort_settings['direction']);
      }
    }

    // Filter by role.
    $handler_settings = $this->configuration['handler_settings'];
    if (!empty($handler_settings['filter']['role'])) {
      $query->condition('roles', $handler_settings['filter']['role'], 'IN');
    }
    return $query;
  }
  
  
  /**
   * {@inheritdoc}
   * 
   */
  public function getReferenceableEntities($match = NULL, $match_operator = 'CONTAINS', $limit = 0) {
      $target_type = $this->configuration['target_type'];

    $query = $this->buildEntityQuery($match, $match_operator);
    if ($limit > 0) {
      $query->range(0, $limit);
    }
    $result = $query->execute()->fetchCol();
    //compare the parent::getReferenceableEntities
    //I think empty($result) behaves differently on an entityQuery, which this override is not

    $options = array();
    $entities = entity_load_multiple($target_type, $result);
    foreach ($entities as $entity_id => $entity) {
      $bundle = $entity->bundle();
      $options[$bundle][$entity_id] = Html::escape($entity->label());
    }

    return $options;
  }

}
