<?php

/**
 * @file
 * Contains \Drupal\cforge\Plugin\DevelGenerate\HamletsUserGenerate.
 */

namespace Drupal\cforge\Plugin\DevelGenerate;

use Drupal\devel_generate\Plugin\DevelGenerate\UserDevelGenerate;

/**
 * Provides a UserDevelGenerate plugin.
 *
 * @DevelGenerate(
 *   id = "hamlets_user",
 *   label = @Translation("Better users"),
 *   description = @Translation("Generate a given number of users with English names. Optionally delete current users."),
 *   url = "user",
 *   permission = "administer devel_generate",
 *   settings = {
 *     "num" = 50,
 *     "kill" = FALSE,
 *     "pass" = ""
 *   }
 * )
 */
class HamletsUserGenerate extends UserDevelGenerate {

  /**
   * The user storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $userStorage;

  /**
   * The date formatter service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected $dateFormatter;

  /**
   * {@inheritdoc}
   */
  protected function generateElements(array $values) {
    $num = $values['num'];
    $kill = $values['kill'];
    $pass = $values['pass'];
    $age = $values['time_range'];
    $roles = array_filter($values['roles']);

    if ($kill) {
      $uids = $this->userStorage->getQuery()
        ->condition('uid', 1, '>')
        ->execute();
      $users = $this->userStorage->loadMultiple($uids);
      $this->userStorage->delete($users);

      $this->setMessage($this->formatPlural(count($uids), '1 user deleted', '@count users deleted.'));
    }

    $first = array('Alice', 'Barry', 'Cherry', 'Dante', 'Ebeneezer', 'Fanny', 'Garry', 'Harry', 'Irma', 'Jerry', 'Kerry', 'Larry', 'Murray', 'Nancy', 'Oliver', 'Perry', 'Quentin', 'Ruby', 'Sylvester', 'Terry', 'Ursula', 'Veronica', 'William', 'Xanadu', 'Yuri', 'Zoe');
    $last = array('Archer', 'Barker', 'Cooper', 'Duke', 'Earl', 'Fisher', 'Gardener', 'Hooper', 'Indignado', 'Joyner', 'Kellogg', 'Leach', 'Mason', 'Nurse', 'Offal', 'Parker', 'Quarkson', 'Rake', 'Smith', 'Turner', 'Undertaker', 'Vicar', 'Waterman', 'X', 'Yardley', 'Zapatero');
    shuffle($first);
    shuffle($last);
  
    if ($num > 0) {
      if (empty($roles)) {
        $roles = array(DRUPAL_AUTHENTICATED_RID);
      }
      
      for ($i = 0; $i < $num; $i++) {
        $account = $this->userStorage->create(array(
          'uid' => NULL,
          'name' => $first[$i],
          'pass' => 'a',
          'mail' => $first[$i] . '@example.com',
          'status' => 1,
          'created' => REQUEST_TIME - mt_rand(0, $age),
          'roles' => array_values($roles),
          // A flag to let hook_user_* know that this is a generated user.
          'devel_generate' => TRUE,
        ));

        // Populate all fields with sample values.
        $this->populateFields($account);
        //replace the default content with a sensible name
        $account->firstname->value = $first[$i];
        $account->lastname->value = $last[$i];
        $account->save();
      }
    }
    $this->setMessage($this->t('@num_users created.', array('@num_users' => $this->formatPlural($num, '1 user', '@count users'))));
  }

}
